Summary:	Software version of a PKCS#11 Hardware Security Module
Name:		softhsm
Version:	2.6.1
Release:	%mkrel 6
License:	BSD
Group:		System/Base
URL:		https://www.opendnssec.org/
Source:		https://www.opendnssec.org/files/source/%{name}-%{version}.tar.gz
Source1:	https://www.opendnssec.org/files/source/%{name}-%{version}.tar.gz.sig
BuildRequires:	pkgconfig(openssl)
BuildRequires:	sqlite3-tools
BuildRequires:	pkgconfig(sqlite3) >= 3.4.2
BuildRequires:	pkgconfig(cppunit)
BuildRequires:	p11-kit-devel
Requires(pre): rpm-helper
Requires(postun): rpm-helper

%description
OpenDNSSEC is providing a software implementation of a generic
cryptographic device with a PKCS#11 interface, the SoftHSM. SoftHSM is
designed to meet the requirements of OpenDNSSEC, but can also work together
with other cryptographic products because of the PKCS#11 interface.

%package	devel
Summary:	Development package of softhsm that includes the header files
Group:		Development/C
Requires:	%{name} = %{version}
Requires:	pkgconfig(openssl)
Requires:	pkgconfig(sqlite3)

%description	devel
This package contains the libsofthsm include files.

%prep
%autosetup -p1

%build
autoreconf -fi

# remove softhsm/ subdir auto-added to --libdir
sed -i 's:full_libdir/softhsm:full_libdir:g' configure

%configure \
    --libdir=%{_libdir}/pkcs11 \
    --with-openssl=%{_prefix} \
    --disable-static \
    --with-crypto-backend=openssl \
    --enable-ecc \
    --disable-eddsa \
    --disable-gost \
    --with-migrate \
    --with-objectstore-backend-db \
    --with-sqlite3=%{_prefix} \
    --enable-visibility \
    --with-p11-kit=%{_datadir}/p11-kit/modules/

%make_build

#check
#make check

%install

%make_install

install -d %{buildroot}%{_includedir}/softhsm
install -m 644 src/lib/*.h %{buildroot}%{_includedir}/softhsm

rm %{buildroot}/etc/softhsm*.conf.sample
rm -f %{buildroot}%{_libdir}//pkcs11/*.la

# leave a softlink where softhsm-1 installed its library. Programs like
# opendnssec have that filename in their configuration file.
install -d %{buildroot}/%{_libdir}/softhsm
ln -s ../pkcs11/libsofthsm2.so %{buildroot}/%{_libdir}/softhsm/libsofthsm.so
# rhbz#1272423 NSS needs it to be in the search path too
( cd  %{buildroot}/%{_libdir} ; ln -s pkcs11/libsofthsm2.so)

%pre
%_pre_useradd %{name} /var/lib/%{name} /sbin/nologin

%postun
%_postun_userdel %{name}

%files
%doc FIPS-NOTES.md LICENSE NEWS README.md
%config(noreplace) %{_sysconfdir}/softhsm2.conf
%{_bindir}/*
%dir %{_libdir}/pkcs11
%{_libdir}/pkcs11/libsofthsm2.so
%{_libdir}/libsofthsm2.so
%{_libdir}/softhsm/libsofthsm.so
%attr(0664,root,root) %{_datadir}/p11-kit/modules/softhsm2.module
%attr(0770,%{name},%{name}) %dir /var/lib/%{name}
%{_mandir}/*/*

%files devel
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h


%changelog
* Sat Jun 28 2025 umeabot <umeabot> 2.6.1-6.mga10
+ Revision: 2220023
- Mageia 10 Mass Rebuild

* Tue Oct 31 2023 daviddavid <daviddavid> 2.6.1-5.mga10
+ Revision: 2003027
- new version: 2.6.1

* Tue Mar 29 2022 umeabot <umeabot> 2.5.0-5.mga9
+ Revision: 1832096
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 2.5.0-4.mga9
+ Revision: 1747987
- rebuild for openssl 3.0.0

* Sat Feb 15 2020 umeabot <umeabot> 2.5.0-3.mga8
+ Revision: 1528242
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Aug 17 2019 guillomovitch <guillomovitch> 2.5.0-2.mga8
+ Revision: 1429594
- add pkcs11 support
- use fedora setup

* Thu Nov 01 2018 daviddavid <daviddavid> 2.5.0-1.mga7
+ Revision: 1327243
- new version: 2.5.0

* Sun Sep 23 2018 umeabot <umeabot> 2.4.0-2.mga7
+ Revision: 1301099
- Mageia 7 Mass Rebuild

* Sat May 19 2018 daviddavid <daviddavid> 2.4.0-1.mga7
+ Revision: 1230411
- new version: 2.4.0

* Wed Sep 06 2017 cjw <cjw> 2.3.0-1.mga7
+ Revision: 1151646
- 2.3.0

* Fri Feb 12 2016 luigiwalser <luigiwalser> 2.0.0-2.mga6
+ Revision: 956075
- rebuild for botan

* Tue Nov 17 2015 oden <oden> 2.0.0-1.mga6
+ Revision: 903789
- fix build
- fix build
- 2.0.0

* Wed Aug 26 2015 cjw <cjw> 1.3.4-6.mga6
+ Revision: 869692
- rebuild with gcc 5

* Wed Oct 15 2014 umeabot <umeabot> 1.3.4-5.mga5
+ Revision: 740428
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.3.4-4.mga5
+ Revision: 689236
- Mageia 5 Mass Rebuild

* Tue May 06 2014 pterjan <pterjan> 1.3.4-3.mga5
+ Revision: 620357
- Worakround configure not finding botan

* Fri Oct 18 2013 umeabot <umeabot> 1.3.4-2.mga4
+ Revision: 521334
- Mageia 4 Mass Rebuild

* Mon Jan 21 2013 oden <oden> 1.3.4-1.mga3
+ Revision: 390442
- imported package softhsm


* Mon Jan 21 2013 Oden Eriksson <oeriksson@mandriva.com> 1.3.4-1.mga2
- fedora import (slightly)
